# GTK+ implementation of the PyMessage widgets.

import rox
import string
from rox import g
import controls

border_width = 3

class PyMessageApp(controls.AppWin, rox.Window):
	def wm_del(win, ev):
		# We don't want to allow WM exits, so return true
		return True

	def __init__(self):
		controls.AppWin.__init__(self)
		rox.Window.__init__(self)
		self.connect("delete_event", self.wm_del)
		self.set_resizable(True)
		self.set_border_width(border_width)
		self.set_position(g.WIN_POS_CENTER)

		self.main_box = g.VBox()
		self.button_box = g.HBox()
		self.add(self.main_box)
		self.main_label = g.Label()
		self.main_label.set_line_wrap(True)
		self.main_box.pack_start(self.main_label, True, True, 5)
		self.main_box.pack_end(self.button_box)
	
	def add_control(self, ctrl):
		#controls.AppWin.add_control(self, ctrl)
		self.control_list.append(ctrl)
		self.main_box.pack_start(ctrl.pack_widget)

	def mainloop(self):
		self.show_all()
		rox.mainloop()

	def set_label_text(self, msg, use_markup = False):
		if use_markup:
			self.main_label.set_markup(msg)
		else:
			self.main_label.set_text(msg)

	def add_button(self, btn):
		btn.btn.connect('clicked', self.exit_app, btn.exit_code)
		self.button_box.pack_start(btn.btn)
		
class PyMessageAlert(controls.AlertWin):
	def __init__(self, msg):
		controls.AlertWin.__init__(self, msg)
		rox.alert(msg)

class PyMessageInfo(controls.InfoWin):
	def __init__(self, msg):
		controls.InfoWin.__init__(self, msg)
		rox.info(msg)

class EntryWrapper(controls.ControlWrapper):
	def __init__(self, data):
		controls.ControlWrapper.__init__(self, data)
		self.main_widget = g.Entry()
		self.main_widget.set_text(self.default_string)
		self.main_widget.set_activates_default(True)
		if self.num_entries == 3 or self.num_entries == 2:
			self.pack_widget = g.HBox()
			self.pack_widget.pack_start(g.Label(self.label_string))
			self.pack_widget.pack_start(self.main_widget)
		else:
			self.pack_widget = self.main_widget
			
	def get_value(self):
		return self.main_widget.get_text()
		
class ComboWrapper(controls.ControlWrapper):
	def __init__(self, data):
		controls.ControlWrapper.__init__(self, data)
		self.main_widget = g.Combo()
		popdown = self.default_string.split(',')
		self.main_widget.set_popdown_strings(popdown)
		self.main_widget.entry.set_activates_default(True)
		if self.num_entries == 3 or self.num_entries == 2:
			self.pack_widget = g.HBox()
			self.pack_widget.pack_start(g.Label(self.label_string))
			self.pack_widget.pack_start(self.main_widget)
		else:
			self.pack_widget = self.main_widget
			
	def get_value(self):
		return self.main_widget.entry.get_text()
		
class CheckWrapper(controls.ControlWrapper, g.CheckButton):
	def __init__(self, data):
		controls.ControlWrapper.__init__(self, data)
		g.CheckButton.__init__(self)
		self.main_widget = self
		self.pack_widget = self
		if self.default_string == '1':
			self.main_widget.set_active(True)
		else:
			self.main_widget.set_active(False)
		if self.num_entries == 3 or self.num_entries == 2:
			self.set_label(self.label_string)
			
	def get_value(self):
		val = self.get_active()
		if val:
			return '1'
		else: 
			return '0'
			
class OptionWrapper(controls.ControlWrapper, g.VBox):
	def __init__(self, data):
		controls.ControlWrapper.__init__(self, data)
		g.VBox.__init__(self)
		labels = self.default_string.split(',')
		self.option_group = None
		self.option_list = []
		self.main_widget = self
		optind = 0
		if self.label_string != '':
			self.pack_start(g.Label(self.label_string))
		for lbl in labels:
			if self.option_group == None:
				self.option_list.append(g.RadioButton())
			else:
				self.option_list.append(g.RadioButton(self.option_list[optind]))
			optind = len(self.option_list) -1
			if self.option_group == None:
				self.option_group = self.option_list[optind].get_group()
			self.option_list[optind].set_label(lbl)
			self.pack_start(self.option_list[optind])
		self.pack_widget = self
		
	def get_value(self):
		val=''
		for opt in range(0,len(self.option_list)):
			if self.option_list[opt].get_active():
				val=opt
		return str(val)
		
class PyMessageButton(controls.ButtonWrapper):
	def __init__(self, btn_spec):
		controls.ButtonWrapper.__init__(self, btn_spec)
		try:
			button_icon = getattr(g, 'STOCK_' + self.icon_name.upper())
			self.btn = rox.ButtonMixed(button_icon, self.btn_caption)
		except:
			self.btn = g.Button(self.btn_caption)
			
	def set_default(self):
		self.btn.set_flags(g.CAN_DEFAULT)
		self.btn.grab_default()
	def set_command(self, action):
		# The action function is assumed to take one argument
		self.btn.connect('clicked', action, self.exit_code)
